function [f] = bessel_trans2(N,k,g,delta)

% compute f(i,j)=integrate(k,J_N(k*delta(i)).*g(:,j));
% N: the Bessel Function number J_N
% k: kgrid constructed in iter_calc.m (1x1998)
% g: Green's function (89x1998)
% delta: delta=p.delta_grid=0:dx:(9*max(delta)) (1x1045) defined in
%     check_and_process_params.m
% assumes a uniformly spaced wave number grid
p.vol = 1;

if(p.vol>=2)
    disp(['INFO: bessel_trans2.m:    size (G) = ' num2str(size(g))]);
    disp(['INFO: bessel_trans2.m: size(delta) = ' num2str(size(delta))]);
end

% Obtain the Bessel functions on a (k*Delta)-grid
% a: the start point on the (k*Delta) grid, clearly min(k)*min(delta)
% b: the end point on the (k*Delta) grid, clearly max(k)*max(delta)
% get_bessels: obtains J_n on a grid of 1e3 points between a and b.
persistent x J0 J1 J2 a b
if length(x)==0
    a=min(k)*min(delta);
    b=max(k)*max(delta);
    [x,J0,J1,J2]=get_bessels(a,b);
    x=x.';
end
if(p.vol>=2)
    disp(['INFO: bessel_trans2.m:   length(x) = ' num2str(length(x))]);
end

if min(k)*min(delta) < a || max(k)*max(delta)> b
    [x,J0,J1,J2]=get_bessels(a,b);
end
if(p.vol>=2)
    disp(['INFO: bessel_trans2.m:    size (G) = ' num2str(size(g))]);
end
% currently G(i,j) == 89x1998 => i=depth, j=wave-number
g=g.';
% after transpose G(i,j) == 1998x89 => i=wave-number, j=depth
[Nk,Nw]=size(g);
if(p.vol>=2)
    disp(['INFO: bessel_trans2.m:    size (G.'') = ' num2str(size(g))]);
end

% Create a integration vector for the kgrid (looks like a mid-point rule)
dk=zeros(size(k));
for i=2:length(k)-1
    dk(i)= (k(i+1)-k(i-1))/2;
end
dk(1)=k(2)-k(1);
dk(end)=k(end)-k(end-1);

if(p.vol>=2)
    disp(['INFO: bessel_trans2.m: Nk = ' num2str(Nk)]);
    disp(['INFO: bessel_trans2.m: Nw = ' num2str(Nw)]);
    disp(['INFO: bessel_trans2.m: size(delta) = ' num2str(size(delta))]);
end

if N==0
    B=J0.';
elseif N==1
    B=J1.';
elseif N==2
    B=J2.';
else
    disp(['INFO: bessel_trans2.m: can''t do J_N, where N = ' num2str(N)]);
end

delta=delta.';
k=k.';
dk=dk.';

if(p.vol>=2)
    disp(['INFO: bessel_trans2.m: size(k.'') = ' num2str(size(k))]);
    disp(['INFO: bessel_trans2.m: size(dk.'') = ' num2str(size(dk))]);
    disp(['INFO: bessel_trans2.m: lengths(delta.'') = ' num2str(length(delta))]);
end

% loop over the 1045 elements in that given by
% check_and_process_params.m
f=zeros(Nw,length(delta));
for i=1:length(delta)
    
    % interpolate from the x=(k*Delta) grid defined above to the delta grid given by
    % check_and_process_params.m
    C=interp1(x,B,k*delta(i),'spline');
    
    %  size(C),size(dk),size(g),
    
    C=C.*dk;
    for j=1:Nw
        s=C.*g(:,j);
        f(j,i)=sum(s);
    end
end


