function [t_out,g,c_out]=calc_green8c(omega_out,k_out,USE_OTF,SRC,OBS,the_t,FIXED_OBS,p,FORCE_RELOAD)

% disp(['INFO: Starting ' mfilename('fullpath') ' SVN $Revision: 117 $']);

% Bug fixes since tdkc15
% Replaced
%    aa =  (omega_out+conj(w))^(-1)/conj(w);
%    bb =  (-omega_out+w).^(-1)/w;
%
% with
%
%    aa = (omega_out+conj(w))^(-1) / real(w);
%    bb = (-omega_out+w).^(-1)     / real(w);

% We now also use the damping from the damping file

% omega_out and k_out are the values for which to calculate Greens functios
% this is doing the calculation for one frequency, but for all k

persistent already_loaded V W omega k model t c

% load the eigenfunctions if needed

if (isempty(already_loaded) || FORCE_RELOAD )
    
    if p.vol>0, disp('INFO: calc_green8c.m : Starting loading eigenfunctions');end
    
    already_loaded=1;
    
    % Load the eigenfunction: V, W 
    [V,W,omega,k,t,model]=load_eigs3(p);
    
    if strcmp(p.truncate,'yes')
        if p.vol>0,disp(['INFO: calc_green8c.m : truncating height grid to' num2str(p.trunc_val)]);end
        % trim the grid down a little
        % called this z which is what it should have always been called
        % we could imple read this reduced grid at the very start
        % z = zeros(size(t));
        
        % If the original eigenvalues are read in then note that model does
        % not have z, but it has an r value which is in fact z.
        
        if strcmp(p.eig_type,'vel_y1y2')
            z = interp1(model.t,model.r,t);
        else
            z = interp1(model.t,model.z,t);
        end
        % t: input  : 1x800 pts : t=0s        to t=2700s
        % z: output : 1x800 pts : z=0.4959Mm to z=-337.4809Mm
        %         % Now combine them into one interval
        %         I = [interval0 interval1 interval2 interval3 interval4];
        
        % this just gives all indices for which the depth is z > -50 Mm.
        % This is the first 355 elements, i.e. from z=0.4959 Mm down to
        % -49.7942 Mm
        
        if p.vol>0,disp('INFO: calc_green8c.m : truncating depth grid');end
        I = find(z>p.trunc_val);
        
        t = t(I);
        %z = z(I);
        V = V(:,:,I); % recall V(mode,Nk,Nt)
        W = W(:,:,I); % recall W(mode,Nk,Nt)
    end
    
    if strcmp(p.prune,'yes')
        if p.vol>0, disp(['INFO: calc_green8c.m : extracting every ' num2str(p.prune_val) 'th element in depth']);end
        I = I(1:p.prune_val:end); % extracts every 4th index
        
        t = t(I);
        %z = z(I);
        V = V(:,:,I); % recall V(mode,Nk,Nt)
        W = W(:,:,I); % recall W(mode,Nk,Nt)
    end
    
    if p.vol>0,disp('INFO: calc_green8c.m : Finished loading eigenfunctions');end
    
    c=interp1(model.t,model.c,t); % interpolate sound speed c onto trimmed/pruned grid.
end

% some error checking
if (max(k_out)>max(k))
    error('ERROR: dont have eigenfunctions for k that large');
end
if (min(k_out)<min(k))
    min(k),
    min(k_out),
    error('ERROR: dont have eigenfunctions for k that small');
end

% get the size of the new eigenfunction set
% This should be the same as the original read in except for the new t grid
%[MAX_N,Nk,Nt]=size(V);
MAX_N=p.max_n;%,~,~]=size(V);
MIN_N=p.min_n;

% get source and observation vectors
if isreal(V) == 0
    error('ERROR: calc_green8c.m : V array is complex so stopping computation');
end
if isreal(W) == 0
    error('ERROR: calc_green8c.m : W array is complex so stopping computation');
end
%S  = zeros();
%Ob = zeros();
if FIXED_OBS == 0  %% if working at fixed source this first one happens if FIXED_OBS==0
    S  = get_S_fixed(SRC,V,W,t,c,the_t,k);
    Ob = get_Ob(OBS,V,W,t,c,k);
elseif FIXED_OBS == 1
    %     [S, S2] = get_S_new(SRC,V,W,t,c,the_t,k); % new term
    S  = get_S(SRC,V,W,t,c,the_t,k);
    Ob = get_Ob_fixed(OBS,V,W,t,c,the_t,k);
end

% now interpolate onto the grid in k that we want the answer on
% we have a grid of 1x786 which goes from k_min to k_max
% We compute S on the kgrid 1x300 same as from eigs

if ndims(S)==2  % this is the case for power at least
    S=fast_interp2(k,S,k_out);
else % this is the case for I17 at least
    % info : size(Snew) = 15x786x800 : size(S)    = 15x300x800
    S=my_interp_v2(k,S,k_out,2); % orig
    %     S2=my_interp_v2(k,S2,k_out,2); % new term
end

if ndims(Ob)==2
    Ob=fast_interp2(k,Ob,k_out);
else % and this is the case for power
    Ob=my_interp_v2(k,Ob,k_out,2);
end

% load damping file, gamma [15x300]

damp = load(p.damping_file);
tmp  = size(damp.gamma);gamma=zeros([(MAX_N+1) tmp(2)]); clear tmp
for j=(MIN_N+1):(MAX_N+1)
    gamma(j,:) = damp.gamma(j,:);
end
clear damp

% interpolate the eigenvalues k-omega onto the new grid
omega_int=my_interp(k,omega,k_out,0,1,2);
gamma_int=my_interp(k,gamma,k_out,0,1,2);
% I checked here that the old way when omega had the damping as its complex
% component that, -imag(omega_int) = gamma_int, with an imagesc().

% allocate space for the result
g=zeros(length(t),length(k_out));
% A=zeros
dfact = p.dfact;

if (FIXED_OBS)
    % for a fixed observation point, move the source
    S=shiftdim(S,2);
    for j=(MIN_N+1):(MAX_N+1)
        for i=1:length(k_out)
            % Construct factor arising from conj(\xi_i) \times \bvec{xi}
            A = Ob(j,i)*S(:,j,i);
            
            % Construct sigma
            w     = omega_int(j,i);
            gamma = gamma_int(j,i);
            sigma = w - 1i * dfact * gamma;
            if (w>p.max_mode_frequency*2*pi/1e3)
                disp('WARNING: calc_green8c.m : w>p.max_mode_frequency*2*pi/1e3');
                A=0;
            end
            
            % Construct Upsilon
            aa =  (omega_out+conj(sigma))^(-1)/w;
            bb =  (-omega_out+sigma).^(-1)/w;
            Upsilon = 0.5 * (aa+bb);
             %Upsilon = 1 / ( w^2 - (omega_out + 1i*gamma)^2 ); % also works
            % Construct Green's Function
            g(:,i)= g(:,i) + Upsilon * A; % another new term
            
        end
    end
else
    % for a fixed source, move the observation point
    Ob=shiftdim(Ob,2);
    for j=(MIN_N+1):(MAX_N+1)
        for i=1:length(k_out)
            % Construct factor arising from conj(\xi_i) \times \bvec{xi}
            A = squeeze(Ob(:,j,i))*S(j,i);
            
            % Construct sigma
            w = omega_int(j,i);
            gamma = gamma_int(j,i);
            sigma = w - 1i * dfact * gamma;
            if (w>p.max_mode_frequency*2*pi/1e3)
                disp('WARNING: calc_green8c.m : w>p.max_mode_frequency*2*pi/1e3');
                A=0;
            end
            
            % Construct Upsilon
            aa =  (omega_out+conj(sigma))^(-1)/w;
            bb =  (-omega_out+sigma).^(-1)/w;
            Upsilon = 0.5 * (aa+bb);
            %Upsilon = 1 / ( w^2 - (omega_out + 1i*gamma)^2 ); % also works
            % Construct Green's Function
            g(:,i)= g(:,i) +  Upsilon * A;
        end
    end
end

t_out=t;
c_out=c;
%g=-1*g/(omega_out*omega_out); %this is to convert from velocity to
%displacement Burston

% The OTF and Filter
if USE_OTF
    %     disp('INFO: calc_green8c.m : using OTF and filter');
    OTF=get_OTF(k_out,p.which_otf);
    
    for i=1:length(k_out)
        g(:,i)=OTF(i)*g(:,i); % so g now seems to be in omega-k space
    end
    
    % make and apply the data analysis filter
    F=make_filter(omega_out,k_out,p);
    F=reshape(F,1,length(k_out));
    
    for i=1:length(k_out)
        g(:,i)=F(i)*g(:,i); % so we have one filter/k. this makes sense.. we could use a usual haming window here if we wanted to....
    end
    
end

% original final division was 
%g=g/((2*pi)^3);
% new final division is 
g=g/(2*pi);
% the other (2pi)^2 is now in the normalization factor in load_eigs3.m

% save([p.out_directory 'I19g.mat'],'g','k_out','w');
% keyboard
% %
% fltr = zeros([length(p.w) length(k)]);
% save([p.out_directory 'filter.mat'], 'fltr');

% load([p.out_directory 'filter.mat']);
% aaa = find( p.w == omega_out )
% fltr(aaa,:) = F;
% clear aaa
% save([p.out_directory 'f ilter.mat'], 'fltr');
% clear fltr

% disp(['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 117 $']);
