function [p]=check_and_process_params(p)

if p.vol,disp(['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 120 $']);end

%  Check input parameter make sense. Convert to c.g.s., except for wave-number in Mm

% Create output directory for results
p.out_directory= [p.out_directory,'/', get_file_name(p.filter_file), '/', p.runnum,'/'];
if p.vol >= 2, disp(['INFO:   - results will be located in ' p.out_directory]); end
if ~exist(p.out_directory,'dir')
    disp(['INFO:   - directory ' p.out_directory ' doesn''t exist']);
    disp('INFO:   - making this directory now');
    try
        system(['/bin/mkdir -p ' p.out_directory]);
    catch ME
        disp(['ERROR:   - can''t create directory ' p.out_directory]);
        rethrow(ME);
    end
end

% check p.main_comp is acceptable
kt=p.main_comp;
kt=lower(kt); % convert to lower case
ok={'kernels', 'greens', 'birch_vel', 'birch_csq', 'power', 'none', 'zeroth_order'};
c=0;
for i=1:length(ok)
    c=c+strcmpi(kt,ok{i});
end
if c==0
    error(['ERROR: check_and_process_params.m : ' kt ' is not a valid kernel type']);
end

% save the lower case version of the calculation type
p.main_comp=kt;

% parse p.SVM to determine which kernels to compute
p.SVM=regexprep(p.SVM,' * ','');
p.SVM=textscan(p.SVM, '%s', 'delimiter', sprintf(','));
for i=1:length(p.SVM{1})
    if ~strcmp(p.SVM{1}{i},'csq')  && ~strcmp(p.SVM{1}{i},'rho')  && ~strcmp(p.SVM{1}{i},'P')    && ...
            ~strcmp(p.SVM{1}{i},'vx')   && ~strcmp(p.SVM{1}{i},'vy')   && ~strcmp(p.SVM{1}{i},'vz')   && ...
            ~strcmp(p.SVM{1}{i},'BxBx') && ~strcmp(p.SVM{1}{i},'BxBy') && ~strcmp(p.SVM{1}{i},'BxBz') && ...
            ~strcmp(p.SVM{1}{i},'ByBy') && ~strcmp(p.SVM{1}{i},'ByBz') && ~strcmp(p.SVM{1}{i},'BzBz')
        error('ERROR: check_and_process_params.m : invalid option for p.SVM, choices must be from csq, rho, P, vx, vy, vz, BxBx, BxBy, BxBz, ByBy, ByBz, BzBz');
    end
end

% parse p.mdpm to determine what to compute
p.mdpm=regexprep(p.mdpm,' * ','');
p.mdpm=textscan(p.mdpm, '%s', 'delimiter', sprintf(','));
for i=1:length(p.mdpm{1})
    if (~strcmp(p.mdpm{1}{i},'mean')  && ~strcmp(p.mdpm{1}{i},'diff')  && ~strcmp(p.mdpm{1}{i},'plus') && ~strcmp(p.mdpm{1}{i},'minus'))
        error('ERROR: check_and_process_params.m : invalid option for p.mdpm, choices must be from mean, diff, plus, minus');
    end
end

check_file(p.model_file,'solar model');
try
    a=my_load(p.model_file,'model_file');
    m=a.m;
    clear a;
catch ME
    disp(['ERROR: check_and_process_params.m : something is wrong with the format of model file, need a' ...
        ' variable called m']);
    rethrow(ME);
end

% check the filter file exists
%if (~strcmp(get_file_name(p.filter_file),'no_filter'))
%    check_file(get_file_name(p.filter_file),'filter');
%end

%if greens function computed by normal modes, check for the greens function
gf=p.greens_function_type;
if strcmp(gf,'normal_mode');
    MAX_N=p.max_n;
    for n=0:MAX_N %% check for all the nec. n
        name_n=[p.eig_file num2str(n)];
        check_file(name_n,'eigenfunction file');
    end
end

% create grid in omega (angular frequency 1/s)
w=linspace(p.min_f,p.max_f,p.N_omega);
w=w*2*pi/1e3;
p.w=w;

% grid in k (Mm^(-1))
k=linspace(p.min_k,p.max_k,p.N_k);
p.k=k;

% distances to compute kernels for (Mm)
delta=linspace(p.min_distance,p.max_distance,p.N_distance);
p.delta=delta;
if min(delta)<0
    error('ERROR: check_and_process_params.m : don''t know what to with negative distance');
end

% grid to compute the integrals (??? integrals are computed in k.. do I ever use dx again) on
%dx=pi/max(p.k)/50; %% grid step set by highest k in the problem
dx=pi/max(p.k)/5;
disp('  ');
disp(['WARNING: check_and_process_params.m : changed dx = dx / ' num2str(p.delta_grid_fact)]);
disp('  ');
dx=dx/p.delta_grid_fact;
if p.vol>1
    disp(['INFO: check_and_process_params.m : dx = ' num2str(dx)]);
    disp(['INFO: check_and_process_params.m : max(delta) = ' num2str(max(delta))]);
end
p.delta_grid=0:dx:(9*max(delta));
if p.vol>1
    disp(['INFO: check_and_process_params.m : size of p.delta_grid =', num2str(size(p.delta_grid))]);
end
disp('WARNING: check_and_process_params.m : put delta grid back to normal');
disp(['WARNING: check_and_process_params.m : size(delta_grid) = ' num2str(size(p.delta_grid))]);

% determine the acoustic observation depth
p.t_obs = interp1(m.z*1e3,m.t,-p.obs_depth);
if (p.t_obs < -500 || p.t_obs > 500 || isnan(p.t_obs)==1)
    error(['ERROR: check_and_process_params.m : t_obs does not make sense: p.t_obs =', num2str(p.t_obs)]);
end

% determine the acoustic source depth
p.t_src = interp1(m.z*1e3,m.t,-p.src_depth);
if (p.t_src < -500 || p.t_src > 500 || isnan(p.t_src)==1)
    error(['ERROR: check_and_process_params.m : t_src does not make sense: p.t_src =', num2str(p.t_src)]);
end

% get length of z grid after pruning and truncating
t = m.t; z = m.z;
if strcmp(p.truncate,'yes')
    I = find( z > p.trunc_val);
    t = t(I);
end
if strcmp(p.prune,'yes')
    I = I(1:p.prune_val:end); % extracts every nth index
    t = t(I);
end
p.t  = t;
p.Nt = length(t);
clear z t
disp(['INFO: check_and_process_params.m : Nt = ' num2str(p.Nt) ]);

if p.vol,disp(['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 120 $']);end

end
