function compute_Kchunk (dist_ind, omega_min_idx, omega_max_idx, max_delta, p)

disp(['INFO: Starting ' mfilename('fullpath') ' SVN $Revision: 120 $ issue 001']);

%  Computes "curly C" (CC) defined by eqn (30)-(32) in Gizon & Birch 2002
%  Computes and saves for each omega and each distance
%  Computes for fractional perturbations of density (rho), pressure (P),
%    and sound-speed squared (csq)
% It is implicitely assumed dw is real: K = real(dw * K) = dw * real(K)

% Get distance and angular frequency corresponding from input paramaters
the_dist  = p.delta(dist_ind);

% grid in offset and x
if strcmp(p.box,'quarter')
    if p.vol<0,disp('INFO: compute_Kchunk.m : computing quarter box');end
    x = linspace(0, 2*max_delta, p.N_gridx);
    y = linspace(0, 2*max_delta, p.N_gridy);
elseif strcmp(p.box,'half')
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing half box');end
    x = linspace(-2*max_delta, 2*max_delta, p.N_gridx);
    y = linspace(0, 2*max_delta, p.N_gridy);
elseif strcmp(p.box,'full')
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing full box');end
    x = linspace(-2*max_delta, 2*max_delta, p.N_gridx);
    y = linspace(-2*max_delta, 2*max_delta, p.N_gridy);
elseif strcmp(p.box,'granule')
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing granule box');end
    % x(5) -> x(16), y(5) -> y(16)
    x = linspace(-1.156248235702515e+01, 1.156248235702515e+01, p.N_gridx);
    y = linspace(-1.156248235702515e+01, 1.156248235702515e+01, p.N_gridy);
elseif strcmp(p.box,'personal')
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing personel box');end
    % x(5) -> x(16), y(5) -> y(16)
    x = linspace(p.xboxl, p.xboxr, p.N_gridx);
    y = linspace(p.yboxl, p.yboxr, p.N_gridy);
end


% geo1.D_x  := \partial_x \Delta = \pl \sqrt[ (x-x_1)^2 + y^2]
%            = (x-x_1) / \Delta  = \hat\mathbf x \cdot \hat\mathbf \Delta_1
% geo1.D_xx := \partial_x \partial_x \Delta  = \partial_x \partial_x \sqrt[ (x-x_1)^2 + y^2]
%            = y^2 / \Delta^3 = [\hat\mathbf y \cdot \hat\mathbf \Delta_1]^2 / \Delta
% geo1.D_xx - geo1.D_yy = -1/\Delta * [ 2 (\hat\mathbf x \cdot \hat\mathbf \Delta_1)^2 - 1 ]
%                       =  1/\Delta * [ 2 (\hat\mathbf y \cdot \hat\mathbf \Delta_1)^2 - 1 ]
geo1=get_geo(x,y,-the_dist/2);
geo2=get_geo(x,y, the_dist/2);

% Define common factor
% cf.the_omega = the_omega;
% cf.the_omega_sq = the_omega * the_omega;
% cf.mzero = calc_mzero(the_omega,p);
% cf.the_omega_sq_twopi7_mzero = cf.the_omega_sq * (2*pi)^7 * calc_mzero(the_omega,p);
% cf.twopi7_mzero = (2*pi)^7 * calc_mzero(the_omega,p);


% Display some comments
if p.vol >= 1 
%     disp(['  - starting to compute frequency index ' num2str(omega_idx) ' out of ' num2str(length(p.w))]);
%     disp(['  - omega index       = ' num2str(omega_idx)]);
%     disp(['  - angular frequency = ' num2str(the_omega*1000) 'mHz']);
%     disp(['  - cyclic frequency  = ' num2str(the_omega/2/pi*1000) 'mHz']);
    disp('INFO: compute_Kchunk.m : Check sound_speed_kernels_new.m.orig for a good version containing lots of info');
end

integral_out_dir=[p.out_directory 'integrals/'];
if ~exist(integral_out_dir,'dir')
    eval(['! mkdir ' integral_out_dir]);
end
integral_out_dir=[p.out_directory 'Kchunks/'];
if ~exist(integral_out_dir,'dir')
    eval(['! mkdir ' integral_out_dir]);
end

d  = p.delta_grid;
Nx = length(x);
Ny = length(y);
Nt = p.Nt;
t  = p.t;
load([p.model_file]);
z  = interp1(m.t, m.z, t);
Nomega = length(omega_min_idx:omega_max_idx);

% Load weights
disp('INFO: compute_Kchunk.m : Weights already have the form 4*pi*conj(W)');
a = load([p.out_directory 'Weights.mat']);
if find(ismember(p.mdpm{1},'mean'))  
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing mean weights');end
    W_mean    = a.W_mean(dist_ind,:);
    data_mean = zeros([Ny Nx Nt]);
end
if find(ismember(p.mdpm{1},'diff')) 
    if p.vol>0,disp('INFO: compute_Kchunk.m : computing diff weights');end
    W_diff    = a.W_diff(dist_ind,:);
    data_diff = zeros([Ny Nx Nt]);
end
if find(ismember(p.mdpm{1},'plus'))
    W_plus    = a.W_mean(dist_ind,:) + 0.5 * a.W_diff(dist_ind,:);
    data_plus = zeros([Ny Nx Nt]);
end
if find(ismember(p.mdpm{1},'minus'))
    W_minus    = a.W_mean(dist_ind,:) - 0.5 * a.W_diff(dist_ind,:);
    data_minus = zeros([Ny Nx Nt]);
end
clear a

% Common factors
twopi7_mzero_array = (2*pi)^7 * calc_mzero(p.w(omega_min_idx:omega_max_idx),p);
if (length(p.w) > 1)
    dw = p.w(2)-p.w(1);
else
    dw = 1;
end

if isreal(dw) == 0
    error('ERROR: compute_Kchunk.m : omega is complex, we have assumed real here real(dw * CC) = dw * real(CC)')
end

% Sound Speed
if find(ismember(p.SVM{1},'csq'))
    svm = 'csq';
  	if ~exist('I3','var'), disp(['INFO: compute_Kchunk.m : computing I3 for ' svm]);
        I3  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I3(:,:,i)  = iter_calc_I3(p,omega_min_idx+i-1); end
    end
    if ~exist('I6','var'), disp(['INFO: compute_Kchunk.m : computing I6 for ' svm]);
        I6  = zeros(size(I3));
        for i = 1:Nomega, I6(:,:,i)  = iter_calc_I6(p,omega_min_idx+i-1); end
    end
    if ~exist('I7','var'), disp(['INFO: compute_Kchunk.m : computing I7 for ' svm]);
        I7  = zeros(size(I3));
        for i = 1:Nomega, I7(:,:,i)  = iter_calc_I7(p,omega_min_idx+i-1); end
    end
    if ~exist('I11','var'), disp(['INFO: compute_Kchunk.m : computing I11 for ' svm]);
        I11  = zeros(size(I3));
        for i = 1:Nomega, I11(:,:,i)  = iter_calc_I11(p,omega_min_idx+i-1); end
    end

    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        the_omega = p.w(omega_idx);
        cf.the_omega_sq = the_omega^2;
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC = compute_csq(Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, I3(:,:,i), I6(:,:,i), I7(:,:,i), I11(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's/cm^3', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
    
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr
    hdr(1,:) = make_card('UNITS',    's/Mm^3', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
    
    % factor of 1e24 converts s/cm^3 -> s/Mm^3
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e24 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e24 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e24 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
    end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e24 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
    end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end

%% Density
 clear I4
 if find(ismember(p.SVM{1},'rho'))
    svm = 'rho';    
    if ~exist('I1','var'), disp(['INFO: compute_Kchunk.m : computing I1 for ' svm]);
        I1  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I1(:,:,i)  = iter_calc_I1(p,omega_min_idx+i-1); end
    end
    if ~exist('I2','var'), disp(['INFO: compute_Kchunk.m : computing I2 for ' svm]);
        I2  = zeros(size(I1));
        for i = 1:Nomega, I2(:,:,i)  = iter_calc_I2(p,omega_min_idx+i-1); end
    end
    if ~exist('I3','var'), disp(['INFO: compute_Kchunk.m : computing I3 for ' svm]);
        I3  = zeros(size(I1));
        for i = 1:Nomega, I3(:,:,i)  = iter_calc_I3(p,omega_min_idx+i-1); end
    end
    if ~exist('I5','var'), disp(['INFO: compute_Kchunk.m : computing I5 for ' svm]);
        I5  = zeros(size(I1));
        for i = 1:Nomega, I5(:,:,i)  = iter_calc_I5(p,omega_min_idx+i-1); end
    end
    if ~exist('I6','var'), disp(['INFO: compute_Kchunk.m : computing I6 for ' svm]);
        I6  = zeros(size(I1));
        for i = 1:Nomega, I6(:,:,i)  = iter_calc_I6(p,omega_min_idx+i-1); end
    end
    if ~exist('I7','var'), disp(['INFO: compute_Kchunk.m : computing I7 for ' svm]);
        I7  = zeros(size(I1));
        for i = 1:Nomega, I7(:,:,i)  = iter_calc_I7(p,omega_min_idx+i-1); end
    end
    if ~exist('I8','var'), disp(['INFO: compute_Kchunk.m : computing I8 for ' svm]);
        I8  = zeros(size(I1));
        for i = 1:Nomega, I8(:,:,i)  = iter_calc_I8(p,omega_min_idx+i-1); end
    end
    if ~exist('I11','var'), disp(['INFO: compute_Kchunk.m : computing I11 for ' svm]);
        I11  = zeros(size(I1));
        for i = 1:Nomega, I11(:,:,i)  = iter_calc_I11(p,omega_min_idx+i-1); end
    end
    if ~exist('I12','var'), disp(['INFO: compute_Kchunk.m : computing I12 for ' svm]);
        I12  = zeros(size(I1));
        for i = 1:Nomega, I12(:,:,i)  = iter_calc_I12(p,omega_min_idx+i-1); end
    end
    
    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        the_omega = p.w(omega_idx);
        cf.the_omega_sq = the_omega^2;
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC = compute_rho(Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, z, I1(:,:,i), I2(:,:,i), I3(:,:,i), I5(:,:,i), I6(:,:,i), I7(:,:,i), I8(:,:,i), I11(:,:,i), I12(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's/cm^3', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
        
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr
    hdr(1,:) = make_card('UNITS',    's/Mm^3', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
       
    % factor of 1e24 converts s/cm^3 -> s/Mm^3
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e24 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e24 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e24 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
    end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e24 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
    end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end

%% Pressure
clear I4 I5
if find(ismember(p.SVM{1},'P'))
    svm = 'P';    
    if ~exist('I3','var'), disp(['INFO: compute_Kchunk.m : computing I3 for ' svm]);
        I3  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I3(:,:,i)  = iter_calc_I3(p,omega_min_idx+i-1);  end
    end
    if ~exist('I6','var'), disp(['INFO: compute_Kchunk.m : computing I6 for ' svm]);
        I6  = zeros(size(I3));
        for i = 1:Nomega, I6(:,:,i)  = iter_calc_I6(p,omega_min_idx+i-1);  end
    end
    if ~exist('I7','var'), disp(['INFO: compute_Kchunk.m : computing I7 for ' svm]);
        I7  = zeros(size(I3));
        for i = 1:Nomega, I7(:,:,i)  = iter_calc_I7(p,omega_min_idx+i-1);  end
    end
    if ~exist('I8','var'), disp(['INFO: compute_Kchunk.m : computing I8 for ' svm]);
        I8  = zeros(size(I3));
        for i = 1:Nomega, I8(:,:,i)  = iter_calc_I8(p,omega_min_idx+i-1);  end
    end
    if ~exist('I11','var'), disp(['INFO: compute_Kchunk.m : computing I11 for ' svm]);
        I11  = zeros(size(I3));
        for i = 1:Nomega, I11(:,:,i) = iter_calc_I11(p,omega_min_idx+i-1); end
    end
    if ~exist('I12','var'), disp(['INFO: compute_Kchunk.m : computing I12 for ' svm]);
        I12  = zeros(size(I3));
        for i = 1:Nomega, I12(:,:,i) = iter_calc_I12(p,omega_min_idx+i-1); end
    end
    if ~exist('I13','var'), disp(['INFO: compute_Kchunk.m : computing I13 for ' svm]);
        I13  = zeros(size(I3));
        for i = 1:Nomega, I13(:,:,i) = iter_calc_I13(p,omega_min_idx+i-1); end
    end
    if ~exist('I14','var'), disp(['INFO: compute_Kchunk.m : computing I14 for ' svm]);
        I14  = zeros(size(I3));
        for i = 1:Nomega, I14(:,:,i) = iter_calc_I14(p,omega_min_idx+i-1); end
    end
    if ~exist('I15','var'), disp(['INFO: compute_Kchunk.m : computing I15 for ' svm]);
        I15  = zeros(size(I3));
        for i = 1:Nomega, I15(:,:,i) = iter_calc_I15(p,omega_min_idx+i-1); end
    end
    if ~exist('I16','var'), disp(['INFO: compute_Kchunk.m : computing I16 for ' svm]);
        I16  = zeros(size(I3));
        for i = 1:Nomega, I16(:,:,i) = iter_calc_I16_gradient(I6(:,:,i), t, d, m); end
    end
    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        the_omega = p.w(omega_idx);
        cf.the_omega_sq = the_omega^2;
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC = compute_P  (Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, I3(:,:,i), I6(:,:,i), I7(:,:,i), I8(:,:,i), I11(:,:,i), I12(:,:,i), I13(:,:,i), I14(:,:,i), I15(:,:,i), I16(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's/cm^3', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
        
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr;
    hdr(1,:) = make_card('UNITS',    's/Mm^3', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');

    % factor of 1e24 converts s/cm^3 -> s/Mm^3
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e24 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e24 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e24 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
    end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e24 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
   end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end

%% Vx
clear I3 I4 I5 I6 I12 I13 I14 I15 I16
if find(ismember(p.SVM{1},'vx'))
    svm = 'vx';    
    if ~exist('I1','var'), disp(['INFO: compute_Kchunk.m : computing I1 for ' svm]);
        I1  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I1(:,:,i)  = iter_calc_I1(p,omega_min_idx+i-1); end
    end
    if ~exist('I2','var'), disp(['INFO: compute_Kchunk.m : computing I2 for ' svm]);
        I2  = zeros(size(I1));
        for i = 1:Nomega, I2(:,:,i)  = iter_calc_I2(p,omega_min_idx+i-1); end
    end
    if ~exist('I7','var'), disp(['INFO: compute_Kchunk.m : computing I7 for ' svm]);
        I7  = zeros(size(I1));
        for i = 1:Nomega, I7(:,:,i)  = iter_calc_I7(p,omega_min_idx+i-1); end
    end
    if ~exist('I8','var'), disp(['INFO: compute_Kchunk.m : computing I8 for ' svm]);
        I8  = zeros(size(I1));
        for i = 1:Nomega, I8(:,:,i)  = iter_calc_I8(p,omega_min_idx+i-1); end
    end
    if ~exist('I9','var'), disp(['INFO: compute_Kchunk.m : computing I9 for ' svm]);
        I9  = zeros(size(I1));
        for i = 1:Nomega, I9(:,:,i)  = iter_calc_I9(p,omega_min_idx+i-1); end
    end
    
    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        cf.the_omega = p.w(omega_idx);
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC = compute_vx (Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, I1(:,:,i), I2(:,:,i), I7(:,:,i), I8(:,:,i), I9(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's^2/cm^4', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
        
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr
    hdr(1,:) = make_card('UNITS',    's^2/Mm^4', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
    
    % factor of 1e32 converts s^2/cm^4 -> s^2/Mm^4
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e32 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e32 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e32 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
    end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e32 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
    end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end

%% Vy
clear I3 I4 I5 I6 I12 I13 I14 I15 I16
if find(ismember(p.SVM{1},'vy'))
    svm = 'vy';    
    if ~exist('I1','var'), disp(['INFO: compute_Kchunk.m : computing I1 for ' svm]);
        I1  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I1(:,:,i)  = iter_calc_I1(p,omega_min_idx+i-1); end
    end
    if ~exist('I2','var'), disp(['INFO: compute_Kchunk.m : computing I2 for ' svm]);
        I2  = zeros(size(I1));
        for i = 1:Nomega, I2(:,:,i)  = iter_calc_I2(p,omega_min_idx+i-1); end
    end
    if ~exist('I7','var'), disp(['INFO: compute_Kchunk.m : computing I7 for ' svm]);
        I7  = zeros(size(I1));
        for i = 1:Nomega, I7(:,:,i)  = iter_calc_I7(p,omega_min_idx+i-1); end
    end
    if ~exist('I8','var'), disp(['INFO: compute_Kchunk.m : computing I8 for ' svm]);
        I8  = zeros(size(I1));
        for i = 1:Nomega, I8(:,:,i)  = iter_calc_I8(p,omega_min_idx+i-1); end
    end
    if ~exist('I9','var'), disp(['INFO: compute_Kchunk.m : computing I9 for ' svm]);
        I9  = zeros(size(I1));
        for i = 1:Nomega, I9(:,:,i)  = iter_calc_I9(p,omega_min_idx+i-1); end
    end
    
    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        cf.the_omega = p.w(omega_idx);
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC = compute_vy (Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, I1(:,:,i), I2(:,:,i), I7(:,:,i), I8(:,:,i), I9(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's^2/cm^4', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
        
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr
    hdr(1,:) = make_card('UNITS',    's^2/Mm^4', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
    
    % factor of 1e32 converts s^2/cm^4 -> s^2/Mm^4
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e32 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e32 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e32 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
   end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e32 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
    end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end

%% Vz
clear I3 I4 I5 I6 I7 I8 I9 I12 I13 I14 I15 I16
if find(ismember(p.SVM{1},'vz'))
    svm = 'vz';    
    if ~exist('I1','var'), disp(['INFO: compute_Kchunk.m : computing I1 for ' svm]);
        I1  = zeros([length(p.delta_grid) Nt Nomega]);
        for i = 1:Nomega, I1(:,:,i)  = iter_calc_I1(p,omega_min_idx+i-1); end
    end
    if ~exist('I2','var'), disp(['INFO: compute_Kchunk.m : computing I2 for ' svm]);
        I2  = zeros(size(I1));
        for i = 1:Nomega, I2(:,:,i)  = iter_calc_I2(p,omega_min_idx+i-1); end
    end
    if ~exist('I10','var'), disp(['INFO: compute_Kchunk.m : computing I10 for ' svm]);
        I10  = zeros(size(I1));
        for i = 1:Nomega, I10(:,:,i)  = iter_calc_I10(p,omega_min_idx+i-1); end
    end
    if ~exist('I11','var'), disp(['INFO: compute_Kchunk.m : computing I11 for ' svm]);
        I11  = zeros(size(I1));
        for i = 1:Nomega, I11(:,:,i)  = iter_calc_I11(p,omega_min_idx+i-1); end
    end
    
    for i = 1:Nomega
        omega_idx = omega_min_idx+i-1;
        cf.the_omega = p.w(omega_idx);
        cf.twopi7_mzero = twopi7_mzero_array(i);
        data_CC =  compute_vz (Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, I1(:,:,i), I2(:,:,i), I10(:,:,i), I11(:,:,i));
        if p.save_CC
            hdr(1,:) = make_card('UNITS',    's^2/cm^4', ['Curly CC for fractional perturbation in ' svm]);
            hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
            hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
            hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');
            fitswrite(real(data_CC), [p.out_directory '/real_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
%             fitswrite(imag(data_CC), [p.out_directory '/imag_CC' svm '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
        end
        if find(ismember(p.mdpm{1},'mean'))
            data_mean  = data_mean +  real(W_mean(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'diff'))
            data_diff  = data_diff +  real(W_diff(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'plus'))
            data_plus  = data_plus +  real(W_plus(omega_idx) .* data_CC);
        end
        if find(ismember(p.mdpm{1},'minus'))
            data_minus = data_minus + real(W_minus(omega_idx) .* data_CC);
        end
    end
        
    disp(['INFO: compute_Kchunk.m : starting saving Kchunk for ' svm])
    clear hdr;
    hdr(1,:) = make_card('UNITS',    's^2/Mm^4', ['Kernel chunk for fractional perturbation in ' svm ' : K(y,x,z)']);
    hdr(2,:) = make_card('OMEGAMIN', p.w(omega_min_idx), 'minumum angular frequency (rad/s)');
    hdr(3,:) = make_card('OMEGAMAX', p.w(omega_max_idx), 'maxumum angular frequency (rad/s)');
    hdr(4,:) = make_card('DISTANCE', the_dist,           'point-to-point distance (Mm)');

    % factor of 1e32 converts s^2/cm^4 -> s^2/Mm^4
    if find(ismember(p.mdpm{1},'mean'))
        data_mean = 1e32 * dw * data_mean;
        fitswrite(data_mean, [p.out_directory '/Kchunks/K' svm '_mean_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_mean = 0;
    end
    if find(ismember(p.mdpm{1},'diff'))
        data_diff = 1e32 * dw * data_diff;
        fitswrite(data_diff, [p.out_directory '/Kchunks/K' svm '_diff_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_diff = 0;
    end
    if find(ismember(p.mdpm{1},'plus'))
        data_plus = 1e32 * dw * data_plus;
        fitswrite(data_plus, [p.out_directory '/Kchunks/K' svm '_plus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_plus = 0;
    end
    if find(ismember(p.mdpm{1},'minus'))
        data_minus = 1e32 * dw * data_minus;
        fitswrite(data_minus, [p.out_directory '/Kchunks/K' svm '_minus_dist' num2str(dist_ind) '_omega' num2str(omega_min_idx) '-' num2str(omega_max_idx) '.fits'],-64,[],[],hdr);
        data_minus = 0;
    end
    disp(['INFO: compute_Kchunk.m : finished saving Kchunks for ' svm])
end


% BxBx
if find(ismember(p.SVM{1},'BxBx')==1)
    if ~exist('I1','var'),  disp('  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I5','var'),  disp('  - computing I5');  I5  = iter_calc_I5(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I9','var'),  disp('  - computing I9');  I9  = iter_calc_I9(p,omega_idx);  end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_BxBx (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I5, I6, I7, I8, I9, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

% BxBy
if find(ismember(p.SVM{1},'BxBy')==1)
    if ~exist('I1','var'),  disp('  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I5','var'),  disp('  - computing I5');  I5  = iter_calc_I5(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I9','var'),  disp('  - computing I9');  I9  = iter_calc_I9(p,omega_idx);  end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_BxBy (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I5, I6, I7, I8, I9, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

% BxBz
if find(ismember(p.SVM{1},'BxBz')==1)
    if ~exist('I1','var'),  disp('  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I5','var'),  disp('  - computing I5');  I5  = iter_calc_I5(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I10','var'), disp('  - computing I10'); I10 = iter_calc_I10(p,omega_idx); end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_BxBz (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I5, I6, I7, I8, I10, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

% ByBy
if find(ismember(p.SVM{1},'ByBy')==1)
    if ~exist('I1','var'),  disp('  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I5','var'),  disp('  - computing I5');  I5  = iter_calc_I5(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I9','var'),  disp('  - computing I9');  I9  = iter_calc_I9(p,omega_idx);  end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_ByBy (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I5, I6, I7, I8, I9, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

% ByBz
if find(ismember(p.SVM{1},'ByBz')==1)
    if ~exist('I1','var'),  disp('  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I5','var'),  disp('  - computing I5');  I5  = iter_calc_I5(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I10','var'), disp('  - computing I10'); I10 = iter_calc_I10(p,omega_idx);  end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_ByBz (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I5, I6, I7, I8, I10, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

% BzBz
if find(ismember(p.SVM{1},'BzBz')==1)
    if ~exist('I1','var'),  disp('INFO:  - computing I1');  I1  = iter_calc_I1(p,omega_idx);  end
    if ~exist('I3','var'),  disp('  - computing I3');  I3  = iter_calc_I3(p,omega_idx);  end
    if ~exist('I4','var'),  disp('  - computing I4');  I4  = iter_calc_I4(p,omega_idx);  end
    if ~exist('I6','var'),  disp('  - computing I6');  I6  = iter_calc_I6(p,omega_idx);  end
    if ~exist('I7','var'),  disp('  - computing I7');  I7  = iter_calc_I7(p,omega_idx);  end
    if ~exist('I8','var'),  disp('  - computing I8');  I8  = iter_calc_I8(p,omega_idx);  end
    if ~exist('I10','var'), disp('  - computing I10'); I10 = iter_calc_I10(p,omega_idx); end
    if ~exist('I11','var'), disp('  - computing I11'); I11 = iter_calc_I11(p,omega_idx); end
    data = compute_BzBz (Ny, Nx , Nt, t, cf, m, d, p, geo1, geo2, I1, I3, I4, I6, I7, I8, I10, I11);
    disp(['  - starting saving CC' p.SVM{1}])
    hdr(1,:) = make_card('UNITS', 'cgs',['curly C for fractional perturbation in ' p.SVM{1} ' : C(y,x,z)']);
    hdr(2,:) = make_card('OMEGA_IDX', the_omega, 'omega index');
    hdr(2,:) = make_card('DISTANCE', the_dist, 'point-to-point distance in Mm');
    fitswrite(data, [p.out_directory 'CC' p.SVM{1} '_dist' num2str(dist_ind) '_omega' num2str(omega_idx) '.fits'],-64,[],[],hdr);
    disp(['  - finished saving CC' p.SVM{1}])
end

save([p.out_directory 'p'], 'p');
save([p.out_directory 'm'], 'm');
clear hdr; hdr(1,:) = make_card('UNITS', 'Mm','horizontal coordinate');fitswrite(x, [p.out_directory 'x.fits'],-64,[],[],hdr);
clear hdr; hdr(1,:) = make_card('UNITS', 'Mm','horizontal coordinate');fitswrite(y, [p.out_directory 'y.fits'],-64,[],[],hdr);
clear hdr; hdr(1,:) = make_card('UNITS', 'Mm','depth');fitswrite(z, [p.out_directory 'z.fits'],-64,[],[],hdr);
clear hdr; hdr(1,:) = make_card('UNITS', 's','acoustic depth');fitswrite(t, [p.out_directory 't.fits'],-64,[],[],hdr);

disp(['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 120 $ issue 000']);

end

