function compute_greens_functions(p)

disp('INFO: compute_greens_functions.m : starting to compute Greens functions');

% Define omega and wavenumber grids for computing Greens functions
w=p.w;
k=p.k;

% Specify input parameters to calc_green8c
%t_obs=p.t_obs;      %
USE_OTF=1;          % do NOT include effect of Optical Transfer Function
SRC=0;              % G^z : vertical component of source
OBS=0;              % G_h : observe horizontal response to source
t_s=p.t_src;        % pick the grid point closest to this depth
FIXED_OBS=0;        % worked at fixed source: G(k, z, \omega, z_s)
F=1;                % read in eigenvalues

% Compute a 2-D Greens function to get t... not very efficient.
[t,g]=calc_green8c(w(1),k,USE_OTF,SRC,OBS,t_s,FIXED_OBS,p,F);

% Set F=0 so to not re-read the eigenvalues
F=0;

% Initialize Greens functions
Gzz = zeros([length(k) length(t) length(w)]);

for j = 1:length(w) % loop over frequency
    disp(['INFO: compute_greens_functions.m : j = ' num2str(j) ' : omega = ' num2str(w(j))]);
    
    % The 4-D Greens function is
    % 
    %    G(k, z, \omega, z^\prime)
    %
    % where k is the wavenumber, \omega is the angular frequency, z and
    % z^\prime are depth coordinates
    %
    % We compute a 2-D Green's function (g) which varies on depth and
    % wavenumber; i.e. it is simply the 4-D Greens function evaluated at a
    % specific angular frequency (\omega) and a specific depth (either z or
    % z^\prime) depending on the input arguments
    %
    % FIXED_OBS = 0 will compute at a specific z^\prime, e.g. z^\prime=z_s
    %  => G(k, z, \omega, z_s)
    %
    % FIXED_OBS = 1 will compute at a specific z, e.g. z=z_{obs}
    %  => G(k, z_{obs}, \omega, z^\prime)
    %
    % The tensorial indicies are determined by
    %
    %    G^{SRC}_{OBS}
    %
    % where
    %
    %    OBS = 0 => h, OBS = 1 => z
    %    SRC = 0 => h, SRC = 1 => z, SRC = 2 => div
    %    SRC = 3
    %    \partial_zs G^z_i(k, z, omega, zs)
   
    % G^z_h
    
    [t,g]=calc_green8c(w(j),k,USE_OTF,SRC,OBS,t_s,FIXED_OBS,p,F);
    
    g = g.';
    Gzz(:,:,j) = g;
    
    % Some typical dimensions for a typical input parameter file might be
    %
    %   g              192x200            614400  double    complex
    %   k                1x200              1600  double
    %   t                1x192              1536  double
    %   w                1x200              1600  double
    % Recall t is the acoustic depth, t = f(z)
end
% Get the depth
load([p.model_file]);
z = interp1(m.t, m.z, t);
z_s = interp1(m.t, m.z, t_s);
disp('INFO: compute_greens_functions.m : saving');
omega=w;
save([p.out_directory 'G' num2str(SRC) '_' num2str(OBS) '_kzomegazs.mat'],'Gzz','z','k','t','omega','t_s','z_s','USE_OTF','FIXED_OBS','-v7.3','SRC','OBS');
disp('INFO: compute_greens_functions.m : finished');
clear z t k w omega Gzz



