function [k, w, P] = compute_power(p)

fprintf(1,'INFO: compute_power.m : starting power computation\n');

% function [k,w,P]=compute_power(p);
%
% compute power spectrum, given input parameters p
%% uses normal mode summation approximation to the Greens functions
%
% P = (2\pi)^6 abs(g)^2 m(w)
%
% assumes sources are spatially uncorrelated

% define the omega/wavenumber grid.
% note that this is the new grid we want to calculate the Power on. This is
% NOT the omega/wavenumber grid corresponding to the eigenfunctions
w=p.w;
k=p.k;

P=zeros(length(w),length(k));

t_obs=p.t_obs;

USE_OTF=1;          %% include the effect of the OTF
OBS=1;              %% observe vertical vel: G_z
SRC=p.source_type;  %% this should = 3 here to give us the derivative part: G_z,z_s
t_s=p.t_src;        %% pick the grid point closest to this depth
FIXED_OBS=0;        %% worked at fixed source: G(\bk, z, \om, z_s)
% that is correct, in the case, we work at fixed source first and later
% find it at t_obs.

% get the greens function
% include the OTF and look at the vertical velocity
% put a source in vertical momentum at t_s

F=1;

for j = 1:length(w) %% loop over new frequency grid
    if p.vol >= 2
        fprintf(1,['INFO: compute_power.m : main loop : j = ' num2str(j) '\n']);
    end
    if j > 1
        F=0;
    end
    [t,g]=calc_green8c(w(j),k,USE_OTF,SRC,OBS,t_s,FIXED_OBS,p,F);
    
  % g is the Green's function as a function of depth and wavenumber
  %
  % FIXED_OBS = 0
  %  => G(k, z, \omega, z_s)
  % 
  % FIXED_OBS = 1
  %  => G(k, z_{obs}, \omega, z) 
  % 
  % G^{SRC}_{OBS}, where
  %
  % OBS = 0 => h, OBS = 1 => z
  % SRC = 0 => h, SRC = 1 => z, SRC = 2 => div
  %
  % SRC = 3
  % \partial_zs G^z_i(k, z, omega, zs)
  % 
  %  - G = 89x196 => z/t = 1x89 and k=196
  % 
  % Here we usually FIXED_OBS = 0, OBS=1, SRC=3, thus
  %
  % \partial_zs G^z_z(k, z, \omega, z_s) | {z_s}
   
  
 
%   Gzz_ACB(1,:,:) = g;
  
  % get answer at the observation depth
  
  P_temp=squeeze(my_interp(t,g,t_obs,0,1,1));

  P(j,:)=abs(P_temp.').^2;

  % source correlation time effect
  
  P(j,:)=P(j,:)*calc_mzero(w(j),p) * w(j) * w(j);

end
%  save('GreensFunction_mode0_nofilt_noOTF.mat', 't', 'k', 'Gzz_ACB', 'w');
%   clear theomega
%   fprintf(1,'INFO: compute_power.m : saved\n');
  
P=(2*pi)^6*P;
fprintf(1,'INFO: compute_power.m : saving power computation\n');

save([p.out_directory 'power'],'P','k','w','p');



