function CCrho = compute_rho (Ny, Nx, Nt, t, cf, m, d, p, geo1, geo2, z, I1, I2, I3, I5, I6, I7, I8, I11, I12)

fprintf(1,['INFO: Starting ' mfilename('fullpath') ' SVN $Revision: 121 $\n']);

method = 'linear';

fprintf(1,'INFO: compute_rho.m : starting computation of CCrho\n');

csq    = (interp1(m.t, m.c, t)).^2;
rho    = interp1(m.t, m.rho, t);
if (length(m.g)==1)
%     fprintf(1,'INFO: compute_scalar.m : length g = 1 -> g is constant -> dgdz = 0\n');
    g      = m.g;
    dgdz   = 0.0;
else
%     fprintf(1,'INFO: compute_scalar.m : length g ne 1 -> g varies with depth -> computing dgdz\n');
    g    = interp1(m.t, m.g, t);
    dgdz = gradient(g,z*1e8);
end

CCrho = zeros([Ny Nx Nt]);
for j = 1:Nt
    fprintf(1,['INFO: compute_rho.m : j = ' num2str(j) '\n']);            
    I1_1  = interp1(d,I1(:,j),geo1.D,method);
    I1_2  = interp1(d,I1(:,j),geo2.D,method);
    I2_1  = interp1(d,I2(:,j),geo1.D,method);
    I2_2  = interp1(d,I2(:,j),geo2.D,method);
    I5_1  = interp1(d,I5(:,j),geo1.D,method);
    I5_2  = interp1(d,I5(:,j),geo2.D,method);
    I6_1  = interp1(d,I6(:,j),geo1.D,method);
    I6_2  = interp1(d,I6(:,j),geo2.D,method);
    I8_1  = interp1(d,I8(:,j),geo1.D,method);
    I8_2  = interp1(d,I8(:,j),geo2.D,method);
    I12_1 = interp1(d,I12(:,j),geo1.D,method);
    I12_2 = interp1(d,I12(:,j),geo2.D,method);
    
    I1_x_1 = -geo1.D_x .* I1_1;
    I1_x_2 = -geo2.D_x .* I1_2;
    I1_y_1 = -geo1.D_y .* I1_1;
    I1_y_2 = -geo2.D_y .* I1_2;
    
    I2_zx_1 = -geo1.D_x .* I5_1;
    I2_zx_2 = -geo2.D_x .* I5_2;
    I2_zy_1 = -geo1.D_y .* I5_1;
    I2_zy_2 = -geo2.D_y .* I5_2;
    
    II1_x_1 = -geo1.D_x .* I8_1;
    II1_x_2 = -geo2.D_x .* I8_2;
    II1_y_1 = -geo1.D_y .* I8_1;
    II1_y_2 = -geo2.D_y .* I8_2;
    
    % Repeat
    I6_1_minus_I3_1  = interp1(d,I6(:,j),geo1.D,method) - interp1(d,I3(:,j),geo1.D,method);
    I6_2_minus_I3_2  = interp1(d,I6(:,j),geo2.D,method) - interp1(d,I3(:,j),geo2.D,method);
    I11_1_minus_I7_1 = interp1(d,I11(:,j),geo1.D,method) - interp1(d,I7(:,j),geo1.D,method);
    I11_2_minus_I7_2 = interp1(d,I11(:,j),geo2.D,method) - interp1(d,I7(:,j),geo2.D,method);
    % End Repeat
    
    rhoterm1 = -csq(j) * (I6_2_minus_I3_2 .* I11_1_minus_I7_1 + conj(I6_1_minus_I3_1) .* conj(I11_2_minus_I7_2));
    rhoterm2 =  cf.the_omega_sq * (I1_x_2 .* II1_x_1 +  I1_y_2 .* II1_y_1 +  I2_2 .* I12_1 + conj(I1_x_1 .* II1_x_2 +  I1_y_1 .* II1_y_2 +  I2_1 .* I12_2));
    
    if length(g) == 1
        gtmp    = g;
        dgdztmp = 0.0;
    elseif length(g) > 1
        gtmp    = g(j);
        dgdztmp = dgdz(j);
    end
    rhoterm3 = -gtmp .* (I2_zx_2 .* II1_x_1 + I2_zy_2 .* II1_y_1 + I6_2 .* I12_1 + conj(I2_zx_1 .* II1_x_2 + I2_zy_1 .* II1_y_2 + I6_1 .* I12_2));
    rhoterm4 = -dgdztmp .* (I2_2 .* I12_1 + conj(I2_1 .* I12_2));
    if p.hydro
        rhoterm5  = gtmp .* (I6_2_minus_I3_2 .* I12_1 + conj(I6_1_minus_I3_1 .* I12_2));
    else
        rhoterm5 = 0.0;
    end
    
    CCrho(:,:,j) = cf.the_omega_sq * cf.twopi7_mzero * rho(j) * (rhoterm1 + rhoterm2 + rhoterm3 + rhoterm4 + rhoterm5);
    
end

fprintf(1,['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 121 $\n']);

end

