function [] = compute_zero_order(p)

% Compute the Power spectrum per unit area per unit time
% as defined by eq (73) in Gizon & Birch 2002, and in 

[k,w,P] = compute_power(p);
if(p.vol>=2)
    disp('INFO: compute_zero_order.m: computed the power spectrum');
end

% Compute cross-correlation using the power (P) on 2 different delta grids
%    - full_xc: computed in the Fourier domain as a function of omega and
%    p.delta_grid
%    - xc: computed in the Fourier domain as a function of omega and p.delta
[full_xc] = calc_xcorr(p, P, p.delta_grid);
[xc]      = calc_xcorr(p, P, p.delta);
if(p.vol>=2)
    disp('INFO: compute_zero_order.m: computed CCs in the fourier domain');
end

% now pass the full_xc with the omega_grid, do some interps
% and inverse FFTs to get it back to time
[time,full_xc_time,w2,xc_int]=xcorr_time(p.w,full_xc.', 4, 8);
full_xc_time=real(full_xc_time);
if (p.vol >= 2)
    disp('INFO: compute_zero_order.m: computed full xcorr in the time domain');
end

% now do precisely the same for the cross-correlation on the otehr grid
[time,xc_time,w2,xc_int]=xcorr_time(p.w,xc.',4,8);
xc_time=real(xc_time);
if(p.vol>= 2)
    disp('INFO: compute_zero_order.m: computed xcorr in the time domain');
end

% compute the weights
[w_grid,W_mean,W_diff]=calc_W_window_v2(time,p.delta,xc_time,p);
% and it is here that we interpolate from the 3201 pt grid to the 200 or
% whatever grid that comes from the input file
% I wonder how much the ends overlap or are close to one another

W_diff=my_interp(w_grid,W_diff,p.w,0,1,2);
W_mean=my_interp(w_grid,W_mean,p.w,0,1,2);

for j=1:length(p.delta)
  if (find_min_width(W_diff(j,:))<10 || find_min_width(W_mean(j,:))<10)
    write_warning(p,'compute_zero_order.m: found a width of less than ten pixels in W');
    write_warning(p,['compute_zero_order.m: at delta grid point of ' num2str(j)]);
  end
end

dir=p.out_directory;
fname=p.input_name;
save([dir 'power'],'P','k','w','p');

delta_grid=p.delta_grid;
xc_omega=full_xc;
xc_time=full_xc_time;
omega=p.w;
save([dir 'full_xcorr'],'delta_grid','time','xc_time','omega','xc_omega');

delta=p.delta_grid;
save([dir 'Weights'],'xc' ,'xc_time' ,'time' ,'W_diff' ,'W_mean','delta','p');

system(['/usr/cp ' fname ' ' dir 'input']);
filt_file=[p.filter_file];

if (~strcmp(filt_file,'no_filter'))
  system(['/usr/cp ' filt_file ' ' dir 'filter']);
end

save([dir 'structure'],'p');


