function [S]= fast_deriv_interp(x,W,s,xi)

% Typically this is passed  
% x  = t'            i.e size(x) = 89x1
% s  = -c.'.^(-1)    i.e size(s) = 89x1
% xi = source depth = 81.104... seconds = t(7) => z(7) on trimmed grid
% W  is u_z or just u : size(W) = 1x300x89 = mode x k x t/z

% disp(['INFO: fast_deriv_interp.m : xi = ' num2str(xi)]);

[N,Nk,Nt]=size(W);

W=shiftdim(W,2); % size(W) = 89x1x300: move t axis to first

I=max(find(x<xi)); % finds max the values of t just before the one desired, t_s% I=6

si=interp1(x,s,xi); % this is typically -1/c(z_s): si-s(7)=0 in the case im studying

dx=x(I+1)-x(I); % this is typicaly dt x(7)-x(6), forward dt good for euler etc
aa=si/dx;
bb=-si/dx;

S=zeros(N,Nk);
method = 'one-sided'; % options: one-sided or centered
if strcmp(method,'one-sided')
    for i=1:Nk
        for j=1:N
            fa=W(I+1,j,i);
            fb=W(I,j,i);
            S(j,i)=aa*fa+bb*fb;
        end
    end
elseif strcmp(method,'centered')
    for i=1:Nk
        for j=1:N
            S(j,i) = si/(2*dx) * (W(I+2,j,i) - W(I,j,i));
        end
    end
end
% this one gives back S(MAX_N,Nk) which is u_n(k,z_s) 
% more usually it is d/dzs u_n(k,z_s)






