function [geo]=get_geo(x,y,x0);
%
% get horizontal geometry
%
x=x*1e8; %% convert to cm for consistency everywhere
y=y*1e8; %% convert to cm
x0=x0*1e8; %% convert to cm

%
% Description

% [X,Y] = meshgrid(x,y) transforms the domain specified by 
%   vectors x and y into arrays X and Y, which can be used 
%   to evaluate functions of two variables and three-dimensional 
%   mesh/surface plots. The rows of the output array X are 
%   copies of the vector x; columns of the output array Y are 
%   copies of the vector y. In this case, since x and y are
%   1 dimensional, then X and Y are both 2-dimensional.
%

[xg,yg]=meshgrid(x,y);

%
% So now we want to get all the distances from the point x0
%  which is typically sent in as +/- the_dist/2. Since, xg-yg are both 
%  2-dimensional, then D will also be 2-dimensional. We then want to 
%  exclude the point which is zero and use the MATLAB function find 
%  to get all those GREATER that zero. Therefore, D is an 2-D array according to
%
%  D(m,n) = distance between (x_n,y_m) and (y_1,x_0)
%
%  where x_0 is the observation point at y_1 (which is always 0) is always the observation
%  point, because if not we can get this by rotations.
%

D=sqrt(  (xg-x0).^2 + yg.^2 );

%

I=find(D>0);

D_x=zeros(size(xg));
D_y=zeros(size(xg));
D_xy=zeros(size(xg));
D_xx=zeros(size(xg));
D_yy=zeros(size(xg));

%
% In the following D(I) simply takes the 2-D array D and expresses
%  this as a 1-D column vector
%

D_x(I)  =  (xg(I)-x0)./D(I);          
D_y(I)  =   yg(I)./D(I);              
D_xy(I) =  -D_x(I) .* D_y(I) ./ D(I); 
D_xx(I) =  yg(I).^2 ./ D(I).^3;
D_yy(I) = (xg(I)-x0).^2 ./ D(I).^3;

geo.D=D/1e8; %% need this one back in Mm
geo.D_x=D_x;
geo.D_y=D_y;
geo.D_xy=D_xy;
geo.D_xx=D_xx;
geo.D_yy=D_yy;

% Does it take longer to express the struct now than on the fly
