function [t_out,g,c_out]=calc_green8c(omega_out,k_out,USE_OTF,SRC,OBS,the_t,FIXED_OBS,p,FORCE_RELOAD)

% omega_out and k_out are the values for which to calculate Greens functios
% this is doing the calculation for one frequency, but for all k

persistent already_loaded V W omega k model t c

% load the eigenfunctions if needed

if (~length(already_loaded) || FORCE_RELOAD )
    
    if (p.vol >=2)
        disp('INFO: from calc_green8c.m');
        disp('      loading eigenfunctions');
    end
    
    already_loaded=1;
    
    % this loads the eigenfunctions
    
    [V,W,omega,k,t,model]=load_eigs2(p);
    
    % trim the grid down a little
    % called this z which is what it should have always been called
    % we could imple read this reduced grid at the very start

    z=interp1(model.t,model.r,t);
    % t: input  : 1x800 pts : t=0s        to t=2700s
    % z: output : 1x800 pts : z=0.4959Mm to z=-337.4809Mm
    
    I=find(z>-50);
    % this just gives all indices for which the depth is z > -50 Mm.
    % This is the first 355 elements, i.e. from z=0.4959 Mm down to -49.7942 Mm
    I=I(1:4:end); % this then gives every fourth index
    %I=I(1:2:end); % this then gives every fourth index

    t=t(I); % then define new ACOUSTIC depth to be only at these points
    z=z(I);
    V=V(:,:,I); % similarly recall that V(mode,Nk,Nt) so take only the reduced points
    W=W(:,:,I); % similarly again
    
    if (p.vol >= 2)
        disp('      completed loading the eigenfunctions');
    end
    
    c=interp1(model.t,model.c,t); % also interpolate the sound speed c onto the trimmed  grid.
end

% some error checking
if (max(k_out)>max(k))
    error('ERROR: dont have eigenfunctions for k that large');
end
if (min(k_out)<min(k))
    min(k),
    min(k_out),
    error('ERROR: dont have eigenfunctions for k that small');
end

% get the size of the new eigenfunction set
% This should be the same as the original read in except for the new t grid
[MAX_N,Nk,Nt]=size(V);

% get source and observation vectors
%
if ~FIXED_OBS   %% if working at fixed source this first one happens if FIXED_OBS==0
    S = get_S_fixed(SRC,V,W,t,c,the_t);
    Ob= get_Ob(OBS,V,W,t,c);
else
    S = get_S(SRC,V,W,t,c,the_t);
    Ob= get_Ob_fixed(OBS,V,W,t,c,the_t);
end

% now interpolate onto the grid in k that we want the answer on

if ndims(S)==2  % this is the case for power at least
    S=fast_interp2(k,S,k_out);
else
    S=my_interp_v2(k,S,k_out,2);
end

if ndims(Ob)==2
    Ob=fast_interp2(k,Ob,k_out);
else % and this is the case for power
    Ob=my_interp_v2(k,Ob,k_out,2);
end

omega_int=my_interp(k,omega,k_out,0,1,2);

% allocate space for the result
g=zeros(length(t),length(k_out));

if (FIXED_OBS)
    % for a fixed observation point, move the source
    S=shiftdim(S,2);
    
    for j=1:MAX_N
        for i=1:length(k_out)
            
            A=Ob(j,i)*S(:,j,i);
            w=omega_int(j,i);
            
            if (real(w)>p.max_mode_frequency*2*pi/1e3)
                A=0;
            end
            
            aa =  (omega_out+conj(w))^(-1)/conj(w);
            bb =  (-omega_out+w).^(-1)/w;
            
            %tmp=aa*conj(A)+bb*A;
            g(:,i)=g(:,i)+0.5*(aa*conj(A)+bb*A);
        end
    end
else
    % for a fixed source, move the observation point
    Ob=shiftdim(Ob,2);
    for j=1:MAX_N
        for i=1:length(k_out)
            A=squeeze(Ob(:,j,i))*S(j,i);
            w= omega_int(j,i);
            if (real(w)>p.max_mode_frequency*2*pi/1e3)
                A=0;
            end
            aa =  (omega_out+conj(w))^(-1)/conj(w);
            bb = (-omega_out+w).^(-1)/w;
         
            %tmp=aa*conj(A)+bb*A;
            
            g(:,i)=g(:,i)+0.5*(aa*conj(A)+bb*A);
        end
    end
end

t_out=t;
c_out=c;

% the OTF and filter
%
% why the hell is filter in the OTF? These should be separate

if USE_OTF
    OTF=get_OTF(k_out,p.which_otf);

    for i=1:length(k_out)
        g(:,i)=OTF(i)*g(:,i); % so g now seems to be in omega-k space
    end

    % make and apply the data analysis filter 

    F=make_filter(omega_out,k_out,p);

    F=reshape(F,1,length(k_out));
    for i=1:length(k_out)
        g(:,i)=F(i)*g(:,i); % so we have one filter/k. this makes sense.. we could use a usual haming window here if we wanted to....
    end    
end

g=g/((2*pi)^3); % This factor is on p588 from Brich, Kosov, Duvall 2004
%g=-1*g/(omega_out*omega_out); %this is to convert from velocity to
%displacement Burston

