function [I, t_out] = iter_calc(p,tw,params,power_of_k,bessel_n,scale, name)

fprintf(1,['INFO: Starting ' mfilename('fullpath') ' SVN $Revision: 120 $\n']);

% iterative integral of a generic product of Greens functions
% and arbitrary bessel function index
% multiply by a scale
% save in the integrals directory in a matlab file with
% the given name

MAX_ITER=30;
MIN_LSCALE=3;

delta=p.delta_grid;
% initial grid is typically 786 points depending on p.k of course
dk=pi/5/max(p.delta_grid);
NK=round((max(p.k)-min(p.k))/dk);
if (NK < length(p.k))
    fprintf(1,'INFO: iter_calc.m : setting kgrid = p.k\n');
    kgrid = p.k;
    NK = length(kgrid);
else
    fprintf(1,'WARNING: iter_calc.m : still setting kgrid = linspace(min(p.k),max(p.k),NK)\n');
    kgrid =linspace(min(p.k),max(p.k),NK);
end

% get the integrand on first grid

[t_out,G]=generic_integrand(params,p,tw,kgrid,power_of_k);
 fprintf(1,'  \n');
 fprintf(1,'WARNING: iter_calc.m : back to normal\n');
 fprintf(1,'  \n');
% save([p.out_directory 'integrals/' name 'integrand'],'G','kgrid','t_out','p','delta');
if G == 0
    fprintf(1,['WARNING: iter_calc.m : G = 0 probably because the filter was zero. tw = ' num2str(tw) '\n']);
else
    % refine the grid
    [lscale,nk]=refine_grid(p,kgrid,G);
    
    if p.vol > 1
        fprintf(1,['lscale = ' num2str(lscale) '\n']);
        fprintf(1,['INFO: iter_calc.m : size G = ' num2str(size(G)) '\n']);
        fprintf(1,['INFO: iter_calc.m : dk (first grid) = ' num2str(dk) '\n']);
        fprintf(1,['INFO: iter_calc.m : Nk (first grid) = ' num2str(NK) '\n']);
        fprintf(1,['INFO: iter_calc.m : nk (after 1 refine_grid) = ' num2str(size(nk)) '\n']);
        %save([p.out_directory 'firstandrefinedgrids'],'nk','kgrid','t_out','G');
    end
    
    iter=0;
    while (lscale < MIN_LSCALE && iter < MAX_ITER)
        iter=iter+1;
        if p.vol>1,fprintf(1,['INFO: iter_calc.m : improving k grid iter= ' num2str(iter) '\n']);end
        
        % integrand on the intermediate grid points
        [t_out,Gnew]=generic_integrand(params,p,tw,nk,power_of_k);
        
        % update the grid and the Greens functions
        [kgrid,I_sort]=sort([kgrid nk]);
        
        % combine results so far
        Gb=zeros(length(t_out),length(kgrid));
        for tt=1:length(t_out)
            v=[G(tt,:) Gnew(tt,:)];
            v=v(I_sort);
            Gb(tt,:)=v;
        end
        G=Gb;
        
        % and refine the grid again
        [lscale,nk]=refine_grid(p,kgrid,G);
        if p.vol>2, fprintf(1,['INFO: iter_calc.m : lscale = ' num2str(lscale) '\n']);end
    end
end

if p.vol > 1
    fprintf(1,['INFO: iter_calc.m : final size G = ' num2str(size(G)) '\n']);
    fprintf(1,['INFO: iter_calc.m : final nk = ' num2str(size(nk)) '\n']);
    fprintf(1,['INFO: iter_calc.m : final kgrid = ' num2str(size(kgrid)) '\n']);
end

% save the integrand +/- a few scales
% save([p.out_directory 'integrals/' name 'integrand_omega' num2str(tw)],'G','kgrid','t_out','p','delta');
% typical size(G): 192        1786

% do the actual integral \int dk J_n(k\Delta)
tmp=bessel_trans2(bessel_n,kgrid,G,delta);
% now multiply by the scale and move the depth grid index to 2nd place
% scale is typically something like, 2*pi*sqrt(-1)*(1e-8)
I=scale*shiftdim(tmp,1); 

% % make sure the directory exists
if strcmp(p.main_comp,'birch_vel')
    str=p.out_directory;
    if ~exist(str,'dir')
        eval(['! mkdir ' str]);
    end
    
    str=[p.out_directory 'integrals/'];
    if ~exist(str,'dir')
        eval(['! mkdir ' str]);
    end
    
    save integral
    save([p.out_directory 'integrals/' name],'I','kgrid','t_out','p');
end

fprintf(1,['INFO: Finishing ' mfilename('fullpath') ' SVN $Revision: 120 $\n']);

