function [I, t]=iter_calc_I1(p,tw)

% Compute
%
%   I_1(\Delta,\omega, z) = i 2 \pi \int_0^\infty dk k J_1(k\Delta) F(k,\omega) G^{*h}_z (k,\omega,z_{obs},z) \\
% 
% tw is the grid point in frequency to compute at
%
% In the following, I use the source type from input file.
% to get the above result, pass p.source_type=1. 
%
% if in doubt, can check in calc_green8c.m and 
% also in generic_integrand.m
%
% This is in fact the same as ABs A1 integral

%
% name of the file to save the integral in  
%
%name=['I1_' num2str(tw)];
name='I1';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The Greens function: F(k,\omega) G_z^h (k,\omega,z_{obs},z)
%  Included the filter with this term
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

params{1}.SRC=0;       %% horizontal source
params{1}.OBS=1;       %% vertical component of displacement       
params{1}.FIXED_OBS=1; %% fixed observation G(k,\omega,z_{obs},z)
params{1}.USE_OTF=1;   %% use the filter F (this includes the OTF)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% here are non-Greens function inputs
% power_of_k is the power of k to appear in the integral
%
% bessel_n is the order of bessel function
% scale is a factor in front of the integral.
% 
% iter_calc assumes that k is in 1/Mm.  We want an answer in cgs
% units, no need to take case of the powers of 1e-8 in scale
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
power_of_k=1; % iter_calc.m converts k from to cm^{-1} before doing the power

% The factor of 1e-8 below is converting the dk from /Mm to /cm.
scale    = 2 * pi * 1i * 1e-8;
bessel_n = 1;

[I, t] =iter_calc(p,tw,params,power_of_k,bessel_n,scale,name);

