function [I]=iter_calc_I7(p,tw)
%
% compute the 7th integral from the Romain Lapole notes 
%
% I_7(\Delta,\omega,z) &=& 2\pi\int dk k^2 J_0(k\Delta) F(k,\omega)  \\
%         && \times  G^{*z}_{z,z_s} (k,\omega,z_obs,z_s) \\
%         && \times     G^z_{h,z_s} (k,omega,z,z_s)
% the second subscript on G denotes a derivative w.r.t. the source depth
% 
% tw is the grid point in frequency to compute at
%
% In the following, I use the source type from input file.
% to get the above result, pass p.source_type=3. (This
% includes G^{*z}_{z,z_s}  G^z_{h,z_s} )
%
%
% if in doubt, can check in calc_green8c.m and 
% also in generic_integrand.m
%


%
% name of the file to save the integral in  
%
%name=['I7_' num2str(tw)];
name='I7';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The Greens function: G^z_{h,z_s} (k,omega,z,z_s)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

params{1}.SRC=p.source_type;       %% Not too sure about this one. I thouht this was divergence
params{1}.OBS=0;       %% get the horizontal component of displacement       
params{1}.FIXED_OBS=0; %% fixed source height
params{1}.USE_OTF=0;   %% use the filter F (this includes the OTF)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The Greens function: F(k,\omega) G^{*z}_{z,z_s}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  
%
% SRC=3 is for a source that is partial_{z_s} \delta(z-z_s)
% here I am using the source type from the input file
% to be general.
%
%
% SRC=0 is the horizontal source
% SRC=1 for a vertical momentum source
% SRC=2 is for a divergence source
%
%
params{2}.SRC=p.source_type;       


%
% OBS=1 is to observe the vertical displacement
% OBS=0 is the horizontal displacement
% OBS=2 is the divergence
% OBS=3 is the z-derivative of the vertical displacement
%
%
params{2}.OBS=1;       



% FIXED_OBS=0 means that the observation height is not fixed
% (** this implies that the source depth is fixed and that
%  the source depth is taken from the input file **)
params{2}.FIXED_OBS=0; %% fixed source height



params{2}.USE_OTF=1;   %% use the filter F (this includes the OTF)
params{2}.conjugate=1;   %% take the complex conjugate
params{2}.single_depth=p.t_obs;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% here are non-Greens function inputs
% power_of_k is the power of k to appear in the integral
%
% bessel_n is the order of bessel function
% scale is a factor in front of the integral.
% 
% iter_calc assumes that k is in 1/Mm.  We want an answer in cgs
% units, no need to take case of the powers of 1e-8 in scale
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
power_of_k=2;
%
% remember an extra power of (1e-8) for the dk
%
%scale=2*pi*(1e-8)^(power_of_k+1);
scale=2*pi*(1e-8);
bessel_n=0;

  

[I, t] =iter_calc(p,tw,params,power_of_k,bessel_n,scale,name);
