function [I]=iter_calc_I8(p,tw)
%
% compute the 8th integral from the Romain Lapole notes 
%
% I_{8} &=& 2\pi\int dk k J_1(k\Delta) F(k,\omega)  \\
%         && \times  G^{*z}_{z,z_s} (k,\omega,z_obs,z_s) \\
%         && \times G^z_{h,z_s} (k,omega,z,z_s)
% the second subscript on G denotes a derivative w.r.t. the source depth
% 
% tw is the grid point in frequency to compute at
%

%
% name of the file to save the integral in  
%
%name=['I8_' num2str(tw)];
name='I8';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The Greens function: G^z_{h,z_s} (k,omega,z,z_s)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

params{1}.SRC=p.source_type;       
params{1}.OBS=0; %% get the horizontal component of displacement       
params{1}.FIXED_OBS=0; %% fixed source height
params{1}.USE_OTF=0;   %% use the filter F (this includes the OTF)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The Greens function: F(k,\omega) G^{*z}_{z,z_s}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
params{2}.SRC=p.source_type;       
params{2}.OBS=1;       
params{2}.FIXED_OBS=0; %% fixed source height
params{2}.USE_OTF=1;   %% use the filter F (this includes the OTF)
params{2}.conjugate=1;   %% take the complex conjugate
params{2}.single_depth=p.t_obs;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% here are non-Greens function inputs
% power_of_k is the power of k to appear in the integral
%
% bessel_n is the order of bessel function
% scale is a factor in front of the integral.
% 
% iter_calc assumes that k is in 1/Mm.  We want an answer in cgs
% units, no need to take case of the powers of 1e-8 in scale
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
power_of_k=1;
%
% remember an extra power of (1e-8) for the dk
%
%scale=2*pi*(1e-8)^(power_of_k+1);
scale=2*pi*(1e-8);
bessel_n=1;

  

[I, t]=iter_calc(p,tw,params,power_of_k,bessel_n,scale,name);
