function [F]=make_filter(w,k,p)

[W,K]=meshgrid(w,k);
F=ones(size(W));

filter_file=p.filter_file;

% if no filter then just return a matrix of ones
if (strcmp(get_file_name(filter_file),'no_filter'))
    return;
else
    filter_params=read_filter(p);
end


% ridge filter
if (filter_params.tom_filter==-1)
    F=make_p1_filter(w,k,p);
elseif (filter_params.tom_filter==-2)
    F=make_p2_filter(w,k,p);
elseif  (filter_params.tom_filter==-3)
    F=make_p3_filter(w,k,p);
elseif  (filter_params.tom_filter==-4)
    F=make_p4_filter(w,k,p);
elseif  (filter_params.tom_filter==-10)
    F=make_f_filter(w,k,p);
    if strcmp(p.f_keep_rm, 'rm')
        disp('INFO: make_filter.m : removing f-mode ridge');
        F =  1. - F;
    end
end

% junwei filter
if filter_params.use_filter==2
    if (p.vol >= 1)
        disp('INFO: you are using a junwei filter');
    end
    F=make_junwei_filter(filter_params.tom_filter,k,w);
    % and then drop out of the function
    return
end


%k,w,vp,vp_width,w_zero,dw,f_mode)
% phase speed filter with given phase speed and width
% f-mode ==1 means cut everything but f

% if ( p.vol >= 2 )
%     filter_params
% end

vp=filter_params.vp;
vp_width=filter_params.vp_width;

% convert to cyclic or angular frequencies in mHz
w_zero=filter_params.w_zero*2*pi*1e-3;
dw=filter_params.dw*2*pi*1e-3;

f_mode=filter_params.f_mode;

[W,K]=meshgrid(w,k);

I=find(K>0);
V=1e10*ones(size(W));
V(I)=W(I)./K(I);

if (filter_params.use_filter==0 && filter_params.tom_filter==0)
    F=ones(size(V)).';
    if (p.vol >= 1)
       disp('INFO: make_filter.m: no filter has been applied');
    end
    return
end

if filter_params.use_filter==1 % phase speed filter + gaussian
    F=exp(-(V-vp).^2/vp_width^2);
    F=F.*exp( -(W-w_zero).^2 / dw^2 );
elseif filter_params.use_filter==3  % phase-speed and bandwidth filter
    F=exp(-(V-vp).^2/vp_width^2);
    F=F.*(  abs(W-w_zero) < dw/2 ); % bandwidth filter
end

if f_mode == 1
    for i=1:length(k)
        U=1e-3/5;  % max flow in Mm/S
        w1=sqrt(274e2*k(i)*1e-8)+k(i)*U;
        w2=w1+4*k(i)*U;
        f=zeros(length(w),1);
        I=find(w<w1);
        f(I)=ones(size(I));
        I=find(w>=w1 & w<=w2);
        f(I)=(1+cos(pi*(w(I)-w1)/(w2-w1)))/2;
        F(i,:)=F(i,:).*(f.');
    end
end 

if f_mode == 2  % remove the fmode,
    for i=1:length(k)
        U=1e-3/5;  % max flow in Mm/S
        w1=sqrt(274e2*k(i)*1e-8)+k(i)*U;
        w2=w1+4*k(i)*U;
        f=ones(length(w),1);
        I=find(w<w1);
        f(I)=zeros(size(I));
        I=find(w>=w1 & w<=w2);
        f(I)=1-(1+cos(pi*(w(I)-w1)/(w2-w1)))/2;
        F(i,:)=F(i,:).*(f.');
    end
end

F=sqrt(F.');

% This filter tom is probably from tom duval

if (filter_params.tom_filter>0)
    % this is the filter on the power spectrum
    Nf=make_tom_filter(filter_params.tom_filter,k,w/2/pi*1e3,filter_params.tom_filter_name);
    % sqrt to get the filter for the signal
    F=F.*sqrt(Nf);
end
