function  power_spectrum(~)

% Part below reads in a power-spectrum computed using hannahs code
% read in P(f,k)

% General
clear
Rsun=696;
pf=.2;

% Read MDI Power
Ph = fitsinfo('/data/seismo1/burston/power_spectrum/powerspectra_general.fits');
P  = fitsread('/data/seismo1/burston/power_spectrum/powerspectra_general.fits');
df=Ph.PrimaryData.Keywords{9,2};
dl=Ph.PrimaryData.Keywords{10,2};
dk=Ph.PrimaryData.Keywords{11,2};
[Nf,Nk]=size(P);
for i = 1:Nk
   k(i)   = (i-1)*dk; % units 1/Mm, not yet cyclic wavenumber
   ell(i) = (i-1)*dl;
end
k=2*pi*k;
for i = 1:Nf
   f(i)   = (i-1)*df;
end
ell=k*Rsun;
w=2*pi*f;

% Read model power spectrum
b=load('/scratch/seismo/burston/TDKC/output/tdkc17/no_filter/run0216/power.mat');
b.f=b.w/2/pi;
b.ell=b.k*Rsun;

% plot indices
krng1=12:237;
frng1=62:124;
kidx1=120;
%kidx2=192; % for 400x400
kidx2=479; % for 1000x1000
fidx1=85;
%fidx2=150; % for 400x400
fidx2=373; % for 1000x1000

subplot(321);
imagesc(ell(krng1),f(frng1)*1e3,log(P(frng1,krng1)/max(max(P(frng1,krng1)))));
set(gca,'YDir','normal');%,'Clim',[-1 1]*6)
xlabel('ell');
ylabel('f (mHz)');
title('MDI 8.5h Dopplergrams : log(P)');

subplot(322)
imagesc(b.k*Rsun,b.w*1e3/2/pi,log(b.P/max(max(b.P))));
set(gca,'YDir','normal');%,'CLim',[0 5]*1e-14);
xlabel('ell');ylabel('f (mHz)');
title('Model : log(P)');

subplot(323)
set(gca,'NextPlot','replace');
plot(f*1e3,P(:,kidx1)/max(P(:,kidx1)));
%plot(f*1e3,log(P(:,kidx1)/max(P(:,kidx1))));
title(['ell = ' num2str(ell(kidx1))])
set(gca,'XLim',[2 4]);
set(gca,'NextPlot','add');
plot(b.w*1e3/2/pi,b.P(:,kidx2)/max(b.P(:,kidx2)),'color','red');
%plot(b.w*1e3/2/pi,log(b.P(:,kidx2)/max(b.P(:,kidx2))),'color','red');
xlabel('f (mHz)');ylabel('Power');

subplot(324)
for i=kidx2
    plot(b.w*1e3/2/pi,b.P(:,kidx2)/max(b.P(:,kidx2)));
%     plot(b.w*1e3/2/pi,log(b.P(:,kidx2)/max(b.P(:,kidx2))));
    title(['ell = ' num2str(b.k(kidx2)*Rsun) ])
    xlabel('f (mHz)');ylabel('Power');
    pause(pf)
end

krng2=110:1000;
subplot(325)
set(gca,'NextPlot','replace');
plot(ell,P(fidx1,:)/max(P(fidx1,krng1)));
%plot(ell,log(P(fidx1,:)/max(P(fidx1,50:237))));
title(['f = ' num2str(f(fidx1)*1e3)])
set(gca,'NextPlot','add');
plot(b.k*Rsun,b.P(fidx2,:)/max(b.P(fidx2,krng2)),'color','red');
%plot(b.k*Rsun,log(b.P(fidx2,:)/max(b.P(fidx2,:))),'color','red');
set(gca,'XLim',[200 800]);
xlabel('ell');ylabel('Power');

subplot(326);
plot(b.k*Rsun,b.P(fidx2,:)/max(b.P(fidx2,krng2)));
%plot(b.k*Rsun,log(b.P(fidx2,:)/max(b.P(fidx2,:))));
title(num2str(b.w(fidx2)*1e3/2/pi))
set(gca,'XLim',[200 800]);
xlabel('ell');ylabel('Power');


% % now save in mat format
% save('/data/seismo1/burston/power_spectrum/powerspectra_general.mat','P','k','f','w','ell')
% 
% % now over plot the Model S eigenfrequencies
% 
% for mode=0:14
%     eig=load(['/data/seismo1/burston/TDKC/PreparedData/Eigensystems/realModelS_cart_nodamp_disp/v7/model_eig' num2str(mode) '.mat']);
%     set(gca,'NextPlot','add');    
%     plot(eig.k*Rsun,eig.omega/2/pi*1e3,'color','red')
% end
% 
% % Interpolate P onto same 1x300 k-grid the eigenfunctions use.
% 
% % for i = 1:Nf
% %     Pnew(i,:) = interp1(k,P(i,:),eig.k);
% % end
% % 
% % imagesc(eig.k*Rsun,f*1e3,log(Pnew));
% % set(gca,'YDir','normal')
% % xlabel('ell');
% % ylabel('f (mHz)');
% % title('log(P)');
% 
% % Make fmode filter
% p.eig_file='/data/seismo1/burston/TDKC/PreparedData/Eigensystems/realModelS_cart_nodamp_disp/v7/model_eig';
% p.filter_case=2;
% F=make_f_filter(w,k,p);F=F';
% imagesc(ell,f*1e3,F);
% set(gca,'YDir','normal')
% xlabel('ell');
% ylabel('f (mHz)');
% title('log(P)');
% 
% % Apply the f-mode filter
% 
% P_f = P .* F;
% 
% % Now plot the fmode power
% 
% imagesc(ell,f*1e3,log(P_f));
% set(gca,'YDir','normal')
% xlabel('ell');
% ylabel('f (mHz)');
% title('log(P)');
% 
% P=P_f;
% save('/data/seismo1/burston/power_spectrum/powerspectra_general.mat','P','k','f','w','ell');


%UNTITLED Summary of this function goes here
%   Detailed explanation goes here

% %cube = fitsread('/SUM30/D281474977124092/S00000/Dopplergram.fits');
% clear;
% show_info -a mt.mdi_256x256x1441 n=50 -AP|grep /SUM30/D281474977124412/S00000/MTcube.fits
% 2005.07.20_12:08:00_TAI 1977.01.01_00:00:00_TAI 720.0   2005.07.21_12:08:00_TAI 1977.01.01_00:00:00_TAI 720.0   240.310364      -32.727272   246.700943      4.834594        0.002094        0.002094        60.000000       696.007385      -0.028930       -0.344100   -0.503700        eqcentre        mdi.fd_v_lev18  trackmap        MPS     drms_mapping    1.02    drms_cube_care          postel  35  35       null    /SUM30/D281474977124412/S00000/MTcube.fits
% 
% cube = fitsread('/SUM30/D281474977124412/S00000/MTcube.fits');
% % 
% % pf=0.1;
% % for i = 1:1441
% % imagesc(cube(:,:,i))
% % pause(pf);
% % end
% 
% [Nx,~,Nt] = size(cube);
% 
% tmp1 = fft(cube,[],1);
% tmp2 = fft(tmp1,[],2);
% tmp3 = ifft(tmp2,[],3);
% 
% power = abs(tmp3);
% 
% kxr=1:128;%128:256
% kwr=720:1441;
% 
% dt = 60.0;
% daxis1 = 0.002094;
% dx = daxis1 * Rsun; % degrees per pix
% dk = 2 * pi / Nx / dx;
% dw = 2 * pi / Nt / dt;
% 
% Nk=Nx/2;
% 
% for i = 1:Nk
%     k(i) = i-1;
% end
% 
% 
% k = (k*(Nk+1)/Nk)  -0.5*dk*Rsun;
% 
% 
% for i = 1:Nt
%     w(i) = i*dw;
% end
% 
% f=w/2/pi;
% 
% imagesc(k*Rsun,f*1e3,flipud(squeeze(log(power(1,kxr,kwr)))'))
% set(gca,'YDir','normal');
% colorbar;
% xlabel('k R_{sun}');
% ylabel('f (mHz)');



